"""
__version__.py
~~~~~~~~~~~~~~

Information about the current version of the py-package-template package.
"""

__title__ = 'lambdasdk'
__description__ = 'for interacting with aws lambda'
__version__ = '0.0.11'
__author__ = 'Nic Wanavit'
__author_email__ = 'nwanavit@hatari.cc'
__license__ = 'Apache 2.0'
__url__ = 'https://github.com/thanakijwanavit/lambda-pip'
